@@ -159,10 +159,14 @@ PrimeInstance::process_remaining_key_event (const KeyEvent &key)
         return false;
 
     if (get_session () && isprint (key.get_ascii_code ())) {
-        if (is_converting () || is_selecting_prediction () ||
+        bool was_preediting = is_preediting ();
+
+        if (is_converting () ||
+            is_selecting_prediction () ||
             (isupper (key.get_ascii_code ()) && m_factory->m_commit_on_upper))
         {
             action_commit (true);
+            was_preediting = false;
         }
 
         char buf[2];
@@ -172,6 +176,14 @@ PrimeInstance::process_remaining_key_event (const KeyEvent &key)
         // finish selecting predictions;
         m_lookup_table.show_cursor (false);
         get_session()->edit_insert (buf);
+
+        if (key.get_ascii_code () == ',' || key.get_ascii_code () == '.') {
+            if (m_factory->m_commit_period && !was_preediting)
+                action_commit (true);
+            else if (m_factory->m_convert_on_period)
+                action_convert ();
+        }
+
         set_preedition ();
 
         return true;
@@ -433,15 +445,21 @@ PrimeInstance::set_preedition (void)
 
             AttributeList attr_list;
             if (!cursor.empty ()) {
-                Attribute attr (left.length (), cursor.length(),
-                                SCIM_ATTR_DECORATE);
-                attr.set_value (SCIM_ATTR_DECORATE_REVERSE);
+                Attribute attr (0, m_candidates[0].m_conversion.length (),
+                                SCIM_ATTR_DECORATE, SCIM_ATTR_DECORATE_REVERSE);
                 attr_list.push_back (attr);
             }
 
-            update_preedit_string (m_candidates[0].m_conversion);
+            update_preedit_string (m_candidates[0].m_conversion, attr_list);
             update_preedit_caret (0);
 
+            attr_list.clear ();
+            if (!cursor.empty ()) {
+                Attribute attr (left.length (), cursor.length(),
+                                SCIM_ATTR_DECORATE, SCIM_ATTR_DECORATE_REVERSE);
+                attr_list.push_back (attr);
+            }
+
             show_aux_string ();
             update_aux_string (left + cursor + right, attr_list);
 
@@ -540,6 +558,13 @@ PrimeInstance::set_preedition_on_register (void)
         attr.set_start (pos);
 
         if (!m_candidates.empty ()) {
+            // preedition
+            preedition = m_candidates[0].m_conversion;
+            str += preedition;
+
+            attr.set_value (SCIM_ATTR_DECORATE_REVERSE);
+
+            // reading
             if (!left.empty () && cursor.empty () && right.empty ())
                 cursor = utf8_mbstowcs (" ");
             reading = left + cursor + right;
@@ -547,14 +572,10 @@ PrimeInstance::set_preedition_on_register (void)
             AttributeList reading_attr_list;
             if (!cursor.empty ()) {
                 Attribute attr (left.length (), cursor.length(),
-                                SCIM_ATTR_DECORATE);
-                attr.set_value (SCIM_ATTR_DECORATE_REVERSE);
+                                SCIM_ATTR_DECORATE, SCIM_ATTR_DECORATE_REVERSE);
                 reading_attr_list.push_back (attr);
             }
 
-            preedition = m_candidates[0].m_conversion;
-            str += preedition;
-
             show_aux_string ();
             update_aux_string (reading, reading_attr_list);
 
@@ -605,19 +626,22 @@ PrimeInstance::set_prediction (void)
 
     m_lookup_table.clear ();
     m_candidates.clear ();
-    get_session()->conv_predict (m_candidates);
-
-    for (unsigned int i = 0; i < m_candidates.size (); i++)
-        m_lookup_table.append_candidate (m_candidates[i].m_conversion);
     m_lookup_table.show_cursor (false);
 
-    unsigned int min_candidates = m_factory->m_inline_prediction ? 1: 0;
+    if (is_preediting ()) {
+        get_session()->conv_predict (m_candidates);
+        for (unsigned int i = 0; i < m_candidates.size (); i++)
+            m_lookup_table.append_candidate (m_candidates[i].m_conversion);
 
-    if (is_preediting () &&
-        m_candidates.size () > min_candidates &&
-        m_candidates[0].m_conversion.length () > 0)
-    {
-        show_lookup_table ();
+        unsigned int min_candidates = m_factory->m_inline_prediction ? 1: 0;
+
+        if (m_candidates.size () > min_candidates &&
+            m_candidates[0].m_conversion.length () > 0)
+        {
+            show_lookup_table ();
+        } else {
+            hide_lookup_table ();
+        }
 
     } else {
         hide_lookup_table ();
@@ -711,6 +735,7 @@ PrimeInstance::action_commit (bool learn)
         reset ();
 
     } else {
+        reset ();
         return false;
     }
 
@@ -1106,8 +1131,8 @@ PrimeInstance::action_edit_backspace (void)
             m_registering_value.erase (m_registering_cursor - 1, 1);
             m_registering_cursor--;
             set_preedition ();
-            return true;
         }
+        return true;
     }
 
     if (!is_preediting ())
@@ -1136,8 +1161,8 @@ PrimeInstance::action_edit_delete (void)
         if (m_registering_cursor < m_registering_value.length ()) {
             m_registering_value.erase (m_registering_cursor, 1);
             set_preedition ();
-            return true;
         }
+        return true;
     }
 
     if (!is_preediting ())
@@ -1192,7 +1217,10 @@ PrimeInstance::action_insert_alternative_space (void)
 bool
 PrimeInstance::action_conv_next_candidate (void)
 {
-    if (is_registering () && !is_preediting ()) {
+    if (is_registering () &&
+        !is_preediting () &&
+        m_registering_value.empty ())
+    {
         action_revert ();
         return true;
     }
@@ -1235,7 +1263,10 @@ PrimeInstance::action_conv_next_candidate (void)
 bool
 PrimeInstance::action_conv_prev_candidate (void)
 {
-    if (is_registering () && !is_preediting ()) {
+    if (is_registering () &&
+        !is_preediting () &&
+        m_registering_value.empty ())
+    {
         action_revert ();
         return true;
     }
