@@ -131,6 +131,8 @@ struct ComboConfigData
 
 // Internal data declaration.
 static String __config_command                     = SCIM_PRIME_CONFIG_COMMAND_DEFAULT;
+static bool   __config_convert_on_period           = SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD_DEFAULT;
+static bool   __config_commit_period               = SCIM_PRIME_CONFIG_COMMIT_PERIOD_DEFAULT;
 static bool   __config_commit_on_upper             = SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT;
 static bool   __config_predict_on_preedition       = SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT;
 static bool   __config_direct_select_on_prediction = SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT;
@@ -144,6 +146,8 @@ static bool   __config_show_comment                = SCIM_PRIME_CONFIG_SHOW_COMM
 static bool __have_changed    = true;
 
 static GtkWidget    * __widget_command                     = 0;
+static GtkWidget    * __widget_convert_on_period           = 0;
+static GtkWidget    * __widget_commit_period               = 0;
 static GtkWidget    * __widget_commit_on_upper             = 0;
 static GtkWidget    * __widget_predict_on_preedition       = 0;
 static GtkWidget    * __widget_direct_select_on_prediction = 0;
@@ -712,9 +716,27 @@ create_options_page ()
     APPEND_ENTRY(_("PRIME command:"), _("The PRIME command to use as conversion engine."),
                  __widget_command, 0);
 
+    /* start conversion on inputting comma or period */
+    __widget_convert_on_period
+        = gtk_check_button_new_with_mnemonic (_("Start conversion on inputting comma or period."));
+    gtk_widget_show (__widget_convert_on_period);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_convert_on_period, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_convert_on_period), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_convert_on_period,
+                          _("Start conversion on inputting comma or period."), NULL);
+
+    /* commit comma and period */
+    __widget_commit_period
+        = gtk_check_button_new_with_mnemonic (_("Commit comma and period immediately."));
+    gtk_widget_show (__widget_commit_period);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_commit_period, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_commit_period), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_commit_period,
+                          _("Commit comma and period immediatly on inputting these characters when no preedition string exists."), NULL);
+
     /* commit on upper */
     __widget_commit_on_upper
-        = gtk_check_button_new_with_mnemonic (_("Commit on inputting upper letter"));
+        = gtk_check_button_new_with_mnemonic (_("Commit on inputting upper letter."));
     gtk_widget_show (__widget_commit_on_upper);
     gtk_box_pack_start (GTK_BOX (vbox), __widget_commit_on_upper, FALSE, FALSE, 4);
     gtk_container_set_border_width (GTK_CONTAINER (__widget_commit_on_upper), 4);
@@ -725,6 +747,12 @@ create_options_page ()
     g_signal_connect ((gpointer) __widget_command, "changed",
                       G_CALLBACK (on_default_editable_changed),
                       &__config_command);
+    g_signal_connect ((gpointer) __widget_convert_on_period, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_convert_on_period);
+    g_signal_connect ((gpointer) __widget_commit_period, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_commit_period);
     g_signal_connect ((gpointer) __widget_commit_on_upper, "toggled",
                       G_CALLBACK (on_default_toggle_button_toggled),
                       &__config_commit_on_upper);
@@ -1036,6 +1064,16 @@ setup_widget_value ()
             GTK_ENTRY (__widget_command),
             __config_command.c_str ());
     }
+    if (__widget_convert_on_period) {
+        gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (__widget_convert_on_period),
+            __config_convert_on_period);
+    }
+    if (__widget_commit_period) {
+        gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (__widget_commit_period),
+            __config_commit_period);
+    }
     if (__widget_commit_on_upper) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_commit_on_upper),
@@ -1104,6 +1142,12 @@ load_config (const ConfigPointer &config)
     __config_command =
         config->read (String (SCIM_PRIME_CONFIG_COMMAND),
                       __config_command);
+    __config_convert_on_period =
+        config->read (String (SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD),
+                      __config_convert_on_period);
+    __config_commit_period =
+        config->read (String (SCIM_PRIME_CONFIG_COMMIT_PERIOD),
+                      __config_commit_period);
     __config_commit_on_upper =
         config->read (String (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER),
                       __config_commit_on_upper);
@@ -1155,6 +1199,10 @@ save_config (const ConfigPointer &config)
 
     config->write (String (SCIM_PRIME_CONFIG_COMMAND),
                    __config_command);
+    config->write (String (SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD),
+                   __config_convert_on_period);
+    config->write (String (SCIM_PRIME_CONFIG_COMMIT_PERIOD),
+                   __config_commit_period);
     config->write (String (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER),
                    __config_commit_on_upper);
 
