@@ -23,6 +23,8 @@
 
 #define SCIM_PRIME_CONFIG_COMMAND                             "/IMEngine/PRIME/Command"
 #define SCIM_PRIME_CONFIG_TYPING_METHOD                       "/IMEngine/PRIME/TypingMethod"
+#define SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD                   "/IMEngine/PRIME/ConvertOnPeriod"
+#define SCIM_PRIME_CONFIG_COMMIT_PERIOD                       "/IMEngine/PRIME/CommitPeriod"
 #define SCIM_PRIME_CONFIG_COMMIT_ON_UPPER                     "/IMEngine/PRIME/CommitOnUpper"
 
 #define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION               "/IMEngine/PRIME/PredictOnPreedition"
@@ -82,14 +84,15 @@
 
 #define SCIM_PRIME_CONFIG_COMMAND_DEFAULT                     "prime"
 #define SCIM_PRIME_CONFIG_TYPING_METHOD_DEFAULT               ""
-
-#define SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT               true
+#define SCIM_PRIME_CONFIG_CONVERT_ON_PERIOD_DEFAULT           false
+#define SCIM_PRIME_CONFIG_COMMIT_PERIOD_DEFAULT               true
 #define SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT             false
 
 #define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT       true
 #define SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT true
 #define SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT           false
 
+#define SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT               true
 #define SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT    true
 #define SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT             true
 #define SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT                  true
